@@ -7,8 +7,9 @@ from typing import Any
 import yaml
 from pydantic import ValidationError
 
-from autograders.base import Autograder
+from rubric.autograders import Autograder, PerCriterionGrader
 from rubric.types import Criterion, EvaluationReport
+from rubric.utils import default_generate_fn
 
 
 class Rubric:
@@ -24,10 +25,12 @@ class Rubric:
     async def grade(
         self,
         to_grade: str,
-        autograder: Autograder,
+        autograder: Autograder | None = None,
         **kwargs: Any,
     ) -> EvaluationReport:
         """Grade text against this rubric using an autograder class or function."""
+        if autograder is None:
+            autograder = PerCriterionGrader(generate_fn=default_generate_fn)
         return await autograder.grade(to_grade=to_grade, rubric=self.rubric)
 
     @staticmethod
