@@ -1,6 +1,5 @@
 """Type definitions for rubrics and evaluation components."""
 
-from enum import Enum
 from typing import Any, Literal, Protocol
 
 from pydantic import BaseModel, ConfigDict
@@ -29,24 +28,10 @@ class EvaluationReport(BaseModel):
     report: list[CriterionReport] | None = None
 
 
-class ModelProvider(Enum):
-    """Supported LLM providers."""
+class GenerateFn(Protocol):
+    """Protocol defining the signature for generate functions."""
 
-    OPENAI = "openai"
-    ANTHROPIC = "anthropic"
-    OPENROUTER = "openrouter"
-
-
-class ModelConfig(BaseModel):
-    """Configuration for which LLM model to use for grading."""
-
-    model: str
-    provider: ModelProvider = ModelProvider.OPENROUTER
-
-    def get_open_router_model_str(self) -> str:
-        if self.provider == ModelProvider.OPENROUTER:
-            return self.model
-        return f"{self.provider.value}/{self.model}"
+    async def __call__(self, system_prompt: str, user_prompt: str, **kwargs: Any) -> str: ...
 
 
 class AutograderFn(Protocol):
@@ -56,6 +41,6 @@ class AutograderFn(Protocol):
         self,
         to_grade: str,
         rubric: list[Criterion],
-        model: ModelConfig,
+        generate_fn: GenerateFn,
         **kwargs: Any,
     ) -> EvaluationReport: ...
